.. csv-table::
   :header: "Package to import", "Single task to import", "PIP package to install", "Stable version"
   :widths: 15, 10, 15, 30

   "`{{ PKG_NAME }} <https://riotkit-do.readthedocs.io/en/latest/usage/importing-tasks.html#in-yaml-syntax>`_", "`{{ PKG_CLASS_NAME }} <https://riotkit-do.readthedocs.io/en/latest/usage/importing-tasks.html#in-yaml-syntax>`_", "pip install {{ PKG_PIP }}== `SELECT VERSION <https://pypi.org/project/{{ PKG_PIP }}/#history>`_", ".. image:: https://badgen.net/pypi/v/{{ PKG_PIP }}"
